# NotePDF

Script to make lined notepages from a PDF slidedeck. For use with notetaking devices such as the Remarkable tablet. 

This project is not connected to Remarkable AS. 

## Installation

The project can be installed directly from PyPI. Variations on 
```sh
pip install notepdf
```
can be used.

## Usage

The script is used
```sh
notepdf <input_file.pdf>
```


## Development

Uses `uv` to syncronise packages and run commands:
```sh
uv sync
uv add <package>
```